/*
 * KalahaView.java
 */
package kalaha;

import java.awt.Color;
import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import javax.swing.JLabel;
import javax.swing.JMenuBar;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import java.awt.event.ActionListener;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.JDialog;
import javax.swing.JFrame;

/**
 * The application's main frame.
 */
public class KalahaView extends FrameView {

    public KalahaView(SingleFrameApplication app) {
        super(app);

        initComponents();

        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();
        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {

            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(false);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {

            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String) (evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer) (evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
    }

    @Action
    public void showAboutBox() {
        if (aboutBox == null) {
            JFrame mainFrame = KalahaApp.getApplication().getMainFrame();
            aboutBox = new KalahaAboutBox(mainFrame);
            aboutBox.setLocationRelativeTo(mainFrame);
        }
        KalahaApp.getApplication().show(aboutBox);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        lblKj = new javax.swing.JLabel();
        lblKa = new javax.swing.JLabel();
        btn1j = new javax.swing.JButton();
        btn2j = new javax.swing.JButton();
        btn3j = new javax.swing.JButton();
        btn4j = new javax.swing.JButton();
        btn5j = new javax.swing.JButton();
        btn6j = new javax.swing.JButton();
        btn6a = new javax.swing.JButton();
        btn5a = new javax.swing.JButton();
        btn4a = new javax.swing.JButton();
        btn3a = new javax.swing.JButton();
        btn2a = new javax.swing.JButton();
        btn1a = new javax.swing.JButton();
        btnJouer = new javax.swing.JButton();
        btnQuitter = new javax.swing.JButton();
        lblAffichage = new javax.swing.JLabel();
        jLabel1 = new javax.swing.JLabel();
        jLabel2 = new javax.swing.JLabel();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        javax.swing.JMenu helpMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem aboutMenuItem = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();

        mainPanel.setName("mainPanel"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(kalaha.KalahaApp.class).getContext().getResourceMap(KalahaView.class);
        lblKj.setBackground(resourceMap.getColor("lblKj.background")); // NOI18N
        lblKj.setFont(resourceMap.getFont("lblKj.font")); // NOI18N
        lblKj.setForeground(resourceMap.getColor("lblKj.foreground")); // NOI18N
        lblKj.setText(resourceMap.getString("lblKj.text")); // NOI18N
        lblKj.setName("lblKj"); // NOI18N

        lblKa.setBackground(resourceMap.getColor("lblKa.background")); // NOI18N
        lblKa.setFont(resourceMap.getFont("lblKa.font")); // NOI18N
        lblKa.setForeground(resourceMap.getColor("lblKa.foreground")); // NOI18N
        lblKa.setText(resourceMap.getString("lblKa.text")); // NOI18N
        lblKa.setName("lblKa"); // NOI18N

        btn1j.setFont(resourceMap.getFont("btn1j.font")); // NOI18N
        btn1j.setForeground(resourceMap.getColor("btn1j.foreground")); // NOI18N
        btn1j.setText(resourceMap.getString("btn1j.text")); // NOI18N
        btn1j.setName("btn1j"); // NOI18N
        btn1j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn1jActionPerformed(evt);
            }
        });

        btn2j.setFont(resourceMap.getFont("btn2j.font")); // NOI18N
        btn2j.setForeground(resourceMap.getColor("btn2j.foreground")); // NOI18N
        btn2j.setText(resourceMap.getString("btn2j.text")); // NOI18N
        btn2j.setName("btn2j"); // NOI18N
        btn2j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn2jActionPerformed(evt);
            }
        });

        btn3j.setFont(resourceMap.getFont("btn3j.font")); // NOI18N
        btn3j.setForeground(resourceMap.getColor("btn3j.foreground")); // NOI18N
        btn3j.setText(resourceMap.getString("btn3j.text")); // NOI18N
        btn3j.setName("btn3j"); // NOI18N
        btn3j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn3jActionPerformed(evt);
            }
        });

        btn4j.setFont(resourceMap.getFont("btn4j.font")); // NOI18N
        btn4j.setForeground(resourceMap.getColor("btn4j.foreground")); // NOI18N
        btn4j.setText(resourceMap.getString("btn4j.text")); // NOI18N
        btn4j.setName("btn4j"); // NOI18N
        btn4j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn4jActionPerformed(evt);
            }
        });

        btn5j.setFont(resourceMap.getFont("btn5j.font")); // NOI18N
        btn5j.setForeground(resourceMap.getColor("btn5j.foreground")); // NOI18N
        btn5j.setText(resourceMap.getString("btn5j.text")); // NOI18N
        btn5j.setName("btn5j"); // NOI18N
        btn5j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn5jActionPerformed(evt);
            }
        });

        btn6j.setFont(resourceMap.getFont("btn6j.font")); // NOI18N
        btn6j.setForeground(resourceMap.getColor("btn6j.foreground")); // NOI18N
        btn6j.setText(resourceMap.getString("btn6j.text")); // NOI18N
        btn6j.setName("btn6j"); // NOI18N
        btn6j.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn6jActionPerformed(evt);
            }
        });

        btn6a.setFont(resourceMap.getFont("btn6a.font")); // NOI18N
        btn6a.setForeground(resourceMap.getColor("btn6a.foreground")); // NOI18N
        btn6a.setText(resourceMap.getString("btn6a.text")); // NOI18N
        btn6a.setName("btn6a"); // NOI18N
        btn6a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn6aActionPerformed(evt);
            }
        });

        btn5a.setFont(resourceMap.getFont("btn5a.font")); // NOI18N
        btn5a.setForeground(resourceMap.getColor("btn5a.foreground")); // NOI18N
        btn5a.setText(resourceMap.getString("btn5a.text")); // NOI18N
        btn5a.setName("btn5a"); // NOI18N
        btn5a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn5aActionPerformed(evt);
            }
        });

        btn4a.setFont(resourceMap.getFont("btn4a.font")); // NOI18N
        btn4a.setForeground(resourceMap.getColor("btn4a.foreground")); // NOI18N
        btn4a.setText(resourceMap.getString("btn4a.text")); // NOI18N
        btn4a.setName("btn4a"); // NOI18N
        btn4a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn4aActionPerformed(evt);
            }
        });

        btn3a.setFont(resourceMap.getFont("btn3a.font")); // NOI18N
        btn3a.setForeground(resourceMap.getColor("btn3a.foreground")); // NOI18N
        btn3a.setText(resourceMap.getString("btn3a.text")); // NOI18N
        btn3a.setName("btn3a"); // NOI18N
        btn3a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn3aActionPerformed(evt);
            }
        });

        btn2a.setFont(resourceMap.getFont("btn2a.font")); // NOI18N
        btn2a.setForeground(resourceMap.getColor("btn2a.foreground")); // NOI18N
        btn2a.setText(resourceMap.getString("btn2a.text")); // NOI18N
        btn2a.setName("btn2a"); // NOI18N
        btn2a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn2aActionPerformed(evt);
            }
        });

        btn1a.setFont(resourceMap.getFont("btn1a.font")); // NOI18N
        btn1a.setForeground(resourceMap.getColor("btn1a.foreground")); // NOI18N
        btn1a.setText(resourceMap.getString("btn1a.text")); // NOI18N
        btn1a.setName("btn1a"); // NOI18N
        btn1a.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btn1aActionPerformed(evt);
            }
        });

        btnJouer.setFont(resourceMap.getFont("btnJouer.font")); // NOI18N
        btnJouer.setForeground(resourceMap.getColor("btnJouer.foreground")); // NOI18N
        btnJouer.setText(resourceMap.getString("btnJouer.text")); // NOI18N
        btnJouer.setName("btnJouer"); // NOI18N
        btnJouer.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnJouerActionPerformed(evt);
            }
        });

        btnQuitter.setFont(resourceMap.getFont("btnQuitter.font")); // NOI18N
        btnQuitter.setForeground(resourceMap.getColor("btnQuitter.foreground")); // NOI18N
        btnQuitter.setText(resourceMap.getString("btnQuitter.text")); // NOI18N
        btnQuitter.setName("btnQuitter"); // NOI18N
        btnQuitter.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnQuitterActionPerformed(evt);
            }
        });

        lblAffichage.setFont(resourceMap.getFont("lblAffichage.font")); // NOI18N
        lblAffichage.setForeground(resourceMap.getColor("lblAffichage.foreground")); // NOI18N
        lblAffichage.setText(resourceMap.getString("lblAffichage.text")); // NOI18N
        lblAffichage.setName("lblAffichage"); // NOI18N

        jLabel1.setFont(resourceMap.getFont("jLabel1.font")); // NOI18N
        jLabel1.setForeground(resourceMap.getColor("jLabel1.foreground")); // NOI18N
        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N

        jLabel2.setFont(resourceMap.getFont("jLabel2.font")); // NOI18N
        jLabel2.setForeground(resourceMap.getColor("jLabel2.foreground")); // NOI18N
        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addGap(50, 50, 50)
                        .addComponent(lblKa)
                        .addGap(46, 46, 46)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addGroup(mainPanelLayout.createSequentialGroup()
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                                    .addComponent(btn1j, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                    .addComponent(btn6a, javax.swing.GroupLayout.PREFERRED_SIZE, 51, javax.swing.GroupLayout.PREFERRED_SIZE))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                    .addComponent(btn5a, 0, 0, Short.MAX_VALUE)
                                    .addComponent(btn2j, javax.swing.GroupLayout.PREFERRED_SIZE, 54, Short.MAX_VALUE))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                                        .addComponent(btn3j, javax.swing.GroupLayout.PREFERRED_SIZE, 49, javax.swing.GroupLayout.PREFERRED_SIZE)
                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                        .addComponent(btn4j, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                        .addComponent(btn5j, javax.swing.GroupLayout.PREFERRED_SIZE, 49, javax.swing.GroupLayout.PREFERRED_SIZE))
                                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                                        .addComponent(btn4a, 0, 0, Short.MAX_VALUE)
                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                        .addComponent(btn3a, javax.swing.GroupLayout.PREFERRED_SIZE, 47, javax.swing.GroupLayout.PREFERRED_SIZE)
                                        .addGap(12, 12, 12)
                                        .addComponent(btn2a, javax.swing.GroupLayout.PREFERRED_SIZE, 49, javax.swing.GroupLayout.PREFERRED_SIZE)))
                                .addGap(18, 18, 18)
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                    .addComponent(btn1a, 0, 0, Short.MAX_VALUE)
                                    .addComponent(btn6j, javax.swing.GroupLayout.PREFERRED_SIZE, 52, Short.MAX_VALUE)))
                            .addComponent(lblAffichage, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(jLabel1)
                        .addGap(159, 159, 159)))
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addGap(36, 36, 36)
                        .addComponent(lblKj)
                        .addGap(210, 210, 210))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 85, Short.MAX_VALUE)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addComponent(btnQuitter)
                            .addComponent(btnJouer))
                        .addGap(76, 76, 76))))
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(244, 244, 244)
                .addComponent(jLabel2)
                .addContainerGap(402, Short.MAX_VALUE))
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, mainPanelLayout.createSequentialGroup()
                        .addGap(15, 15, 15)
                        .addComponent(jLabel2)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(btn6a)
                            .addComponent(btn5a)
                            .addComponent(btn4a)
                            .addComponent(btn3a)
                            .addComponent(btn1a)
                            .addComponent(btn2a)
                            .addComponent(btnJouer))
                        .addGap(28, 28, 28)
                        .addComponent(lblAffichage, javax.swing.GroupLayout.PREFERRED_SIZE, 65, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, mainPanelLayout.createSequentialGroup()
                        .addGap(105, 105, 105)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(lblKj, javax.swing.GroupLayout.PREFERRED_SIZE, 57, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(lblKa, javax.swing.GroupLayout.PREFERRED_SIZE, 64, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 18, Short.MAX_VALUE)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(btn1j)
                            .addComponent(btn2j)
                            .addComponent(btn3j)
                            .addComponent(btn4j)
                            .addComponent(btn6j)
                            .addComponent(btn5j))
                        .addGap(18, 18, 18)
                        .addComponent(jLabel1)
                        .addGap(18, 18, 18))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addComponent(btnQuitter)
                        .addGap(30, 30, 30))))
        );

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setText(resourceMap.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(kalaha.KalahaApp.class).getContext().getActionMap(KalahaView.class, this);
        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setAction(actionMap.get("showAboutBox")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        statusPanel.setName("statusPanel"); // NOI18N

        statusPanelSeparator.setName("statusPanelSeparator"); // NOI18N

        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(statusPanelSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, 697, Short.MAX_VALUE)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(statusMessageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 527, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusAnimationLabel)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addComponent(statusPanelSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 2, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(statusMessageLabel)
                    .addComponent(statusAnimationLabel)
                    .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(3, 3, 3))
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents
//méthode permettant d'afficher le contenue des cases du jeu
    private void afficherContenuCases() {
        // cases adversaire
        btn1a.setText(String.valueOf(monJeu.casesAdv[0]));
        btn2a.setText(String.valueOf(monJeu.casesAdv[1]));
        btn3a.setText(String.valueOf(monJeu.casesAdv[2]));
        btn4a.setText(String.valueOf(monJeu.casesAdv[3]));
        btn5a.setText(String.valueOf(monJeu.casesAdv[4]));
        btn6a.setText(String.valueOf(monJeu.casesAdv[5]));
        lblKa.setText(String.valueOf(monJeu.kalahaA[0]));

        // cases joueur
        btn1j.setText(String.valueOf(monJeu.casesJoueur[0]));
        btn2j.setText(String.valueOf(monJeu.casesJoueur[1]));
        btn3j.setText(String.valueOf(monJeu.casesJoueur[2]));
        btn4j.setText(String.valueOf(monJeu.casesJoueur[3]));
        btn5j.setText(String.valueOf(monJeu.casesJoueur[4]));
        btn6j.setText(String.valueOf(monJeu.casesJoueur[5]));
        lblKj.setText(String.valueOf(monJeu.kalahaJ[0]));

    }
// méthode permettant de verifier si la case choisie par le joueur 2 n'est pas nulle
    private void validationAdv(int nb) {

        if (monJeu.casesAdv[nb] != 0) {
            monJeu.CoupA(nb);
        } else {
            lblAffichage.setText("Case vide!! Choisir une autre case!!");
        }
    }
// méthode permettant de verifier si la case choisie par le joueur 1 n'est pas nulle
    private void validationJoueur(int nb) {
        if (monJeu.casesJoueur[nb] != 0) {
            monJeu.CoupJ(nb);
        } else {
            lblAffichage.setText("Case vide!! Choisir une autre case!!");
        }
    }
// méthode permettant de tester si c'est la fin du jeu et afficher le gagnant!
    private void Fin() {
        if (monJeu.kalahaA[0] + monJeu.kalahaJ[0] == 36) {
            if (monJeu.kalahaJ[0] > monJeu.kalahaA[0]) {
                lblAffichage.setText("Joueur 1 Gagne!!!");
            } else {
                if (monJeu.kalahaJ[0] < monJeu.kalahaA[0]) {
                    lblAffichage.setText("Joueur 2 Gagne!!!");
                } else {
                    lblAffichage.setText("Ex aequo!!!");
                }
            }
        }
    }
    private boolean tourJ = true;
    private boolean bJ = true;
// méthode empechant a un joueur de jouer si ce n'est pas son tour
    private boolean tour() {
        boolean testTour = true;
        if (tourJ) {
            if (!bJ) {
                lblAffichage.setText("C'est au tour du Joueur 1! Petit malin !");
                testTour = false;
            }


        } else {

            if (bJ) {
                lblAffichage.setText("C'est au tour du Joueur 2! Petit malin !");
                testTour = false;
            }
        }
        return testTour;
    }
    private Cases monJeu;
    private void btnJouerActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnJouerActionPerformed
// Ce bouton crée une parie et initialise le plateau
        monJeu = new Cases();
        monJeu.Début();
        afficherContenuCases();
        lblAffichage.setText("Le Joueur 1 commence!");
        btnJouer.setText("Recommencer");

    }//GEN-LAST:event_btnJouerActionPerformed
/*
   Chaque bouton fonctionne de la même manière d'abord il indique à quel joueur appartient la case selectionnée avec le booleen BJ
   Puis réinitialise l'affichage
   Enfin si c'est le bon joueur qui joue il test la validité de la case, réaffiche le contenu des cases et donne la main à l'adversaire.

*/
    private void btn1aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn1aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(0);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }
    }//GEN-LAST:event_btn1aActionPerformed

    private void btn2aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn2aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(1);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }
    }//GEN-LAST:event_btn2aActionPerformed

    private void btn3aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn3aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(2);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }

    }//GEN-LAST:event_btn3aActionPerformed

    private void btn4aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn4aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(3);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }

    }//GEN-LAST:event_btn4aActionPerformed

    private void btn5aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn5aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(4);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }
    }//GEN-LAST:event_btn5aActionPerformed

    private void btn6aActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn6aActionPerformed
        bJ = false;
        lblAffichage.setText("");
        if (tour()) {
            validationAdv(5);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = true;
            }
            Fin();
        }
    }//GEN-LAST:event_btn6aActionPerformed

    private void btn1jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn1jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(0);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }
    }//GEN-LAST:event_btn1jActionPerformed

    private void btn2jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn2jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(1);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }
    }//GEN-LAST:event_btn2jActionPerformed

    private void btn3jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn3jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(2);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }

    }//GEN-LAST:event_btn3jActionPerformed

    private void btn4jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn4jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(3);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }
    }//GEN-LAST:event_btn4jActionPerformed

    private void btn5jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn5jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(4);
            afficherContenuCases();
            if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }
    }//GEN-LAST:event_btn5jActionPerformed

    private void btn6jActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btn6jActionPerformed
        bJ = true;
        lblAffichage.setText("");
        if (tour()) {
            validationJoueur(5);
            afficherContenuCases();
           if(!monJeu.rejoue){
            tourJ = false;
            }
            Fin();
        }
    }//GEN-LAST:event_btn6jActionPerformed

    private void btnQuitterActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnQuitterActionPerformed
// Ce bouton permet de quitter la partie
        System.exit(0);
    }//GEN-LAST:event_btnQuitterActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btn1a;
    private javax.swing.JButton btn1j;
    private javax.swing.JButton btn2a;
    private javax.swing.JButton btn2j;
    private javax.swing.JButton btn3a;
    private javax.swing.JButton btn3j;
    private javax.swing.JButton btn4a;
    private javax.swing.JButton btn4j;
    private javax.swing.JButton btn5a;
    private javax.swing.JButton btn5j;
    private javax.swing.JButton btn6a;
    private javax.swing.JButton btn6j;
    private javax.swing.JButton btnJouer;
    private javax.swing.JButton btnQuitter;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel lblAffichage;
    private javax.swing.JLabel lblKa;
    private javax.swing.JLabel lblKj;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JProgressBar progressBar;
    private javax.swing.JLabel statusAnimationLabel;
    private javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    // End of variables declaration//GEN-END:variables
    private final Timer messageTimer;
    private final Timer busyIconTimer;
    private final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;
    private JDialog aboutBox;
}
